(function ($) {
	"use strict";

    /*************************
     Variables
    *************************/

     // After Submitting the Contact form, you can change the success Title or the message in case of error
     var title = "Thank you for contacting us"; // Change the title here
     var errorMsg = "Something went wrong. Please try again later." // Change the error message here
     let mobile = window.matchMedia("(max-width: 992px)");
     var is_safari = navigator.userAgent.indexOf('Safari') != -1 && navigator.userAgent.indexOf('Chrome') == -1;

    /*************************
     On Page Load
    *************************/

    $( document ).ready(function() {
        
        // Sticky Header
        showStickyHeader();

        // Magnific Popup
        addMagnificPopup();
        
        // Add it only on the index page
        if ( $("body").hasClass("index")) {
            $.scrollIt();

            // Smooth Scroll to anchor link
            smoothScroll("#about");
            smoothScroll("#contact");

            // Scroll to the top of the page
            scrollToTop();
        }
        
        if ( $("body").hasClass("generateImg")) {
            generateImages();
        }

        // Slick Carousel
        slickCarousel();

        // Hack to fix display issue on Gallery on Safari
        if (is_safari) {
            $("body").addClass("is_safari")
        }
    });

    /*************************
     On Window Scroll
    *************************/

    $(window).scroll(function(){
        showStickyHeader();
    });

    /*************************
     On Window Resize
    *************************/

    $(window).resize(function() {
        if ( $("body").hasClass("hasCarousel")) {
            $(".slider-for").slick("setPosition");
        }
    });

    /*************************
     Show mobile menu
    *************************/ 

    $(document).on("click", ".burger", function() {
        $(this).toggleClass("active");
        $("nav").toggleClass("active");

        if ($(this).hasClass("active")) {
            $("body").css("overflow", "hidden");
        } else {
            $("body").css("overflow", "");
        }
    });

    /*************************
     Hide mobile menu when 
     click on a link
    *************************/ 

    if (mobile) {
        $("nav a").click(function(){
            var navBurger = $("nav, .burger");

            navBurger.removeClass("active");

        });
    }

    /*************************
     Process Contact Form
    *************************/ 

     $( "#contactform").submit(function( event ) {
        event.preventDefault();
        var form = $(this),
            actionUrl = form.attr("action");

        $(".spinner").show();
        $("#contactform").hide();

        $.ajax({
          url: actionUrl,
          data:$(this).serialize(),
          type:"POST",
          success:function(response){   
            $(".spinner").hide();
            $(".contactFormMessage").prepend("<p>"+response+"</p>");
            $(".contactFormMessage").prepend("<h6>"+title+"</h6>");
            $(".contactFormMessage").show();
          },
          error: function (xhr, textStatus) { 
            $(".spinner").hide();
            $(".contactFormMessage").addClass("error").show();
            $(".contactFormMessage h6").html(textStatus);
            $(".contactFormMessage p").html(errorMsg);
          }
        });
        
      });

    /*************************
     Display Form
    *************************/ 

    $(document).on("click", ".displayForm", function() {
    
        if ($(".contactFormMessage").hasClass("error")) {
            $(".contactFormMessage").removeClass("error")
        }

        $(".contactFormMessage").hide();
        $(".contactFormMessage").find("h6, p").remove();
        $("#contactform").find("input, textarea").val("");
        $("#contactform").show();

    });

    /*************************
     Functions
    *************************/ 

    function showStickyHeader() {
        var header = $("header"),
            scroll = $(window).scrollTop();
        
        if (scroll > 80) {
            $(header).addClass("sticky");
            if($(header).hasClass("noShadow")) {
                $(header).removeClass("noShadow");
            }
        } else {
            $(header).removeClass("sticky");
            if($("body").hasClass("index")) {
                $(header).addClass("noShadow");
            }
        }
    }
    
    function generateImages() {
        var container = document.querySelector(".generatedImg"), // get the container
            imgArray = [],
            totalImages = 12,              // Change the number of total images here
            folder = "portfolio/",        // Folder Name
            imageName = "image";          // Change the image name here
            
            // Append image names to Array
            for (let i = 1; i <= totalImages; i++) {
                imgArray.push(`${folder}${imageName}${i}.jpg`);
            }
            
            // Append Template to HTML
            imgArray.forEach((element, index) => {
                var template = 
                    `<a href="${element}" class="galleryItem">
                        <img src="${element}"  alt="Image ${index + 1}" />
                    </a>`;

            container.innerHTML += template;
            }); 
    }

    function slickCarousel() {
        if ( $("body").hasClass("hasCarousel")) {
            $(".slider-for").slick({
                slidesToShow: 1,
                slidesToScroll: 1,
                arrows: false,
                fade: true,
                asNavFor: ".slider-nav"
            });

            $(".slider-nav").slick({
                slidesToShow: 5,
                slidesToScroll: 1,
                asNavFor: ".slider-for",
                dots: false,
                centerMode: true,
                focusOnSelect: true,
                variableWidth: true,
                responsive: [
                    {
                    breakpoint: 992,
                    settings: {
                        slidesToShow: 3
                    }
                    },
                    {
                    breakpoint: 768,
                    settings: {
                        slidesToShow: 2
                    }
                    },
                    {
                    breakpoint: 480,
                    settings: {
                        slidesToShow: 1
                    },
                    },
                ],
            });
        }
    }

    function addMagnificPopup() {
        // Add Magnific popup only in portfolio page
        if ( $("body").hasClass("portfolio")) {
            $(".magnificPopup").magnificPopup({
                delegate: "a", // child items selector, by clicking on it popup will open
                type: "image",
                gallery: {
                    enabled: true
                }
            });
        }
    }

    function smoothScroll(id) {
        $(".smoothScroll").on('click', function (event) {
            event.preventDefault();

            var $this = $(this),
                thisHref = $this.attr('href');

            if (thisHref === id) {
                $('html, body').animate({
                    scrollTop: $(`${id}`).offset().top
                }, 1500);
            }
        });  
    }

    function scrollToTop() {
        $(".scrollToTop").on('click', function (event) {
            event.preventDefault();
            $('html, body').animate({scrollTop: '0px'}, 1500);
        })
    }
})(jQuery)